@@ -5,5 +5,8 @@
 #undef HAVE_STPCPY
 #undef PACKAGE
 #undef VERSION
-#undef GLD_DEBUG
-#undef GLD_LOCALE_DIR
+#undef GLADE_DEBUG
+#undef GLADE_LOCALE_DIR
+#undef GLADE_DATA_DIR
+#undef USE_GNOME
+#undef PALETTE_TYPE
